@@ -1,13 +1,12 @@
 /*
  * Copyright © 2019 Zander Brown <zbrown@gnome.org>
  *
- * SPDX-License-Identifier: GPL-3.0+
+ * SPDX-License-Identifier: GPL-3.0-or-later
  */
 
 #include <gio/gio.h>
 #include <gio/gdesktopappinfo.h>
 
-#define HANDY_USE_UNSTABLE_API
 #include <handy.h>
 
 #pragma once
@@ -22,7 +21,8 @@ struct _PhoshAppGridClass
   GtkBoxClass parent_class;
 };
 
-void phosh_app_grid_reset (PhoshAppGrid *self);
 GtkWidget *phosh_app_grid_new (void);
+void       phosh_app_grid_reset (PhoshAppGrid *self);
+void       phosh_app_grid_focus_search (PhoshAppGrid *self);
 
 G_END_DECLS
