@@ -1,6 +1,8 @@
 /*
  * Copyright (C) 2020 Purism SPC
- * SPDX-License-Identifier: GPL-3.0+
+ *
+ * SPDX-License-Identifier: GPL-3.0-or-later
+ *
  * Author: Guido Günther <agx@sigxcpu.org>
  */
 
@@ -82,6 +84,7 @@ typedef struct _PhoshMediaPlayer {
 
 G_DEFINE_TYPE (PhoshMediaPlayer, phosh_media_player, GTK_TYPE_GRID);
 
+
 static void
 phosh_media_player_get_property (GObject    *object,
                                  guint       property_id,
@@ -103,6 +106,7 @@ phosh_media_player_get_property (GObject    *object,
   }
 }
 
+
 static void
 set_playable (PhoshMediaPlayer *self, gboolean playable)
 {
@@ -114,6 +118,7 @@ set_playable (PhoshMediaPlayer *self, gboolean playable)
   g_object_notify_by_pspec (G_OBJECT (self), props[PROP_PLAYABLE]);
 }
 
+
 static void
 set_attached (PhoshMediaPlayer *self, gboolean attached)
 {
@@ -126,6 +131,7 @@ set_attached (PhoshMediaPlayer *self, gboolean attached)
   g_object_notify_by_pspec (G_OBJECT (self), props[PROP_ATTACHED]);
 }
 
+
 static void
 on_play_pause_done (PhoshMprisDBusMediaPlayer2Player *player,
                     GAsyncResult                     *res,
@@ -141,6 +147,7 @@ on_play_pause_done (PhoshMprisDBusMediaPlayer2Player *player,
   }
 }
 
+
 static void
 btn_play_clicked_cb (PhoshMediaPlayer *self, GtkButton *button)
 {
@@ -154,6 +161,7 @@ btn_play_clicked_cb (PhoshMediaPlayer *self, GtkButton *button)
                                                          self);
 }
 
+
 static void
 on_next_done (PhoshMprisDBusMediaPlayer2Player *player, GAsyncResult *res, PhoshMediaPlayer *self)
 {
@@ -166,6 +174,7 @@ on_next_done (PhoshMprisDBusMediaPlayer2Player *player, GAsyncResult *res, Phosh
     g_warning ("Failed to trigger next: %s", err->message);
 }
 
+
 static void
 btn_next_clicked_cb (PhoshMediaPlayer *self, GtkButton *button)
 {
@@ -179,6 +188,7 @@ btn_next_clicked_cb (PhoshMediaPlayer *self, GtkButton *button)
                                                    self);
 }
 
+
 static void
 on_previous_done (PhoshMprisDBusMediaPlayer2Player *player, GAsyncResult *res, PhoshMediaPlayer *self)
 {
@@ -191,6 +201,7 @@ on_previous_done (PhoshMprisDBusMediaPlayer2Player *player, GAsyncResult *res, P
     g_warning ("Failed to trigger prev: %s", err->message);
 }
 
+
 static void
 btn_prev_clicked_cb (PhoshMediaPlayer *self, GtkButton *button)
 {
@@ -204,6 +215,7 @@ btn_prev_clicked_cb (PhoshMediaPlayer *self, GtkButton *button)
                                                        self);
 }
 
+
 static void
 on_raise_done (PhoshMprisDBusMediaPlayer2 *mpris, GAsyncResult *res, PhoshMediaPlayer *self)
 {
@@ -220,6 +232,7 @@ on_raise_done (PhoshMprisDBusMediaPlayer2 *mpris, GAsyncResult *res, PhoshMediaP
   g_signal_emit (self, signals[PLAYER_RAISED], 0);
 }
 
+
 static void
 btn_details_clicked_cb (PhoshMediaPlayer *self, GtkButton *button)
 {
@@ -237,12 +250,13 @@ btn_details_clicked_cb (PhoshMediaPlayer *self, GtkButton *button)
                                              self);
 }
 
+
 static void
 on_metadata_changed (PhoshMediaPlayer *self, GParamSpec *psepc, PhoshMprisDBusMediaPlayer2Player *player)
 {
   GVariant *metadata;
-  gchar *title = NULL;
-  gchar *url = NULL;
+  char *title = NULL;
+  char *url = NULL;
 
   g_auto (GStrv) artist = NULL;
   g_auto (GVariantDict) dict = G_VARIANT_DICT_INIT (NULL);
@@ -259,15 +273,17 @@ on_metadata_changed (PhoshMediaPlayer *self, GParamSpec *psepc, PhoshMprisDBusMe
   if (title) {
     gtk_label_set_label (GTK_LABEL (self->lbl_title), title);
   } else {
-    gtk_label_set_label (GTK_LABEL (self->lbl_title), _("Unknown title"));
+    /* Translators: Used when the title of a song is unknown */
+    gtk_label_set_label (GTK_LABEL (self->lbl_title), _("Unknown Title"));
   }
 
   g_variant_dict_lookup (&dict, "xesam:artist", "^as", &artist);
   if (artist && g_strv_length (artist) > 0) {
-    g_autofree gchar *artists = g_strjoinv (", ", artist);
+    g_autofree char *artists = g_strjoinv (", ", artist);
     gtk_label_set_label (GTK_LABEL (self->lbl_artist), artists);
   } else {
-    gtk_label_set_label (GTK_LABEL (self->lbl_artist), _("Unknown artist"));
+    /* Translators: Used when the artist of a song is unknown */
+    gtk_label_set_label (GTK_LABEL (self->lbl_artist), _("Unknown Artist"));
   }
 
   g_variant_dict_lookup (&dict, "mpris:artUrl", "&s", &url);
@@ -284,6 +300,7 @@ on_metadata_changed (PhoshMediaPlayer *self, GParamSpec *psepc, PhoshMprisDBusMe
   }
 }
 
+
 static void
 on_playback_status_changed (PhoshMediaPlayer                 *self,
                             GParamSpec                       *psepc,
@@ -339,6 +356,7 @@ on_can_go_next_changed (PhoshMediaPlayer                 *self,
   gtk_widget_set_sensitive (self->btn_next, sensitive);
 }
 
+
 static void
 on_can_go_previous_changed (PhoshMediaPlayer                 *self,
                             GParamSpec                       *psepc,
@@ -352,6 +370,7 @@ on_can_go_previous_changed (PhoshMediaPlayer                 *self,
   gtk_widget_set_sensitive (self->btn_prev, sensitive);
 }
 
+
 static void
 on_can_play (PhoshMediaPlayer                 *self,
              GParamSpec                       *psepc,
@@ -365,6 +384,7 @@ on_can_play (PhoshMediaPlayer                 *self,
   gtk_widget_set_sensitive (self->btn_play, sensitive);
 }
 
+
 static void
 phosh_media_player_dispose (GObject *object)
 {
@@ -449,6 +469,7 @@ phosh_media_player_class_init (PhoshMediaPlayerClass *klass)
   gtk_widget_class_bind_template_callback (widget_class, btn_details_clicked_cb);
 }
 
+
 static void
 attach_player_cb (GObject          *source_object,
                   GAsyncResult     *res,
@@ -497,6 +518,7 @@ out:
   g_object_unref (self);
 }
 
+
 static void
 attach_mpris_cb (GObject          *source_object,
                  GAsyncResult     *res,
@@ -520,8 +542,9 @@ attach_mpris_cb (GObject          *source_object,
   g_object_unref (self);
 }
 
+
 static void
-attach_player (PhoshMediaPlayer *self, const gchar *name)
+attach_player (PhoshMediaPlayer *self, const char *name)
 {
   g_autoptr (GError) err = NULL;
 
@@ -551,8 +574,9 @@ attach_player (PhoshMediaPlayer *self, const gchar *name)
     g_object_ref (self));
 }
 
+
 static gboolean
-is_valid_player (const gchar *bus_name)
+is_valid_player (const char *bus_name)
 {
   if (!g_str_has_prefix (bus_name, MPRIS_PREFIX))
     return FALSE;
@@ -563,6 +587,7 @@ is_valid_player (const gchar *bus_name)
   return TRUE;
 }
 
+
 static void
 find_player_cb (GObject          *source_object,
                 GAsyncResult     *res,
@@ -571,7 +596,7 @@ find_player_cb (GObject          *source_object,
   g_autoptr (GVariant) result = NULL;
   g_autoptr (GVariant) names = NULL;
   g_autoptr (GError) err = NULL;
-  const gchar *name;
+  const char *name;
   GVariantIter iter;
   gboolean found = FALSE;
 
@@ -607,6 +632,7 @@ out:
   g_object_unref (self);
 }
 
+
 static void
 find_player_async (PhoshMediaPlayer *self)
 {
@@ -626,12 +652,13 @@ find_player_async (PhoshMediaPlayer *self)
                           g_object_ref (self));
 }
 
+
 static void
 on_dbus_name_owner_changed (GDBusConnection  *connection,
-                            const gchar      *sender_name,
-                            const gchar      *object_path,
-                            const gchar      *interface_name,
-                            const gchar      *signal_name,
+                            const char       *sender_name,
+                            const char       *object_path,
+                            const char       *interface_name,
+                            const char       *signal_name,
                             GVariant         *parameters,
                             PhoshMediaPlayer *self)
 {
@@ -656,6 +683,7 @@ on_dbus_name_owner_changed (GDBusConnection  *connection,
   attach_player (self, name);
 }
 
+
 static void
 on_bus_get_finished (GObject          *source_object,
                      GAsyncResult     *res,
@@ -688,6 +716,7 @@ out:
   g_object_unref (self);
 }
 
+
 static gboolean
 on_idle (PhoshMediaPlayer *self)
 {
@@ -698,6 +727,7 @@ on_idle (PhoshMediaPlayer *self)
   return G_SOURCE_REMOVE;
 }
 
+
 static void
 phosh_media_player_init (PhoshMediaPlayer *self)
 {
