@@ -1,7 +1,7 @@
 /*
  * Copyright (C) 2018 Purism SPC
  *
- * SPDX-License-Identifier: GPL-3.0+
+ * SPDX-License-Identifier: GPL-3.0-or-later
  */
 
 #pragma once
@@ -14,9 +14,14 @@ G_DECLARE_FINAL_TYPE (PhoshPanel, phosh_panel, PHOSH, PANEL, PhoshLayerSurface)
 
 #define PHOSH_PANEL_HEIGHT 32
 
+/**
+ * PhoshPanelState:
+ * @PHOSH_PANEL_STATE_FOLDED: Only top-bar is visible
+ * @PHOSH_PANEL_STATE_UNFOLDED: Settings menu is unfolded
+ */
 typedef enum {
-  PHOSH_PANEL_STATE_FOLDED,    /* Only top-bar is visible */
-  PHOSH_PANEL_STATE_UNFOLDED,  /* Settings menu is unfolded */
+  PHOSH_PANEL_STATE_FOLDED,
+  PHOSH_PANEL_STATE_UNFOLDED,
 } PhoshPanelState;
 
 GtkWidget * phosh_panel_new (struct zwlr_layer_shell_v1 *layer_shell,
@@ -24,3 +29,4 @@ GtkWidget * phosh_panel_new (struct zwlr_layer_shell_v1 *layer_shell,
 void        phosh_panel_toggle_fold (PhoshPanel *self);
 void        phosh_panel_fold (PhoshPanel *self);
 void        phosh_panel_unfold (PhoshPanel *self);
+PhoshPanelState phosh_panel_get_state (PhoshPanel *self);
