@@ -1,9 +1,11 @@
 /*
  * Copyright (C) 2019 Purism SPC
- * SPDX-License-Identifier: GPL-3.0+
+ *
+ * SPDX-License-Identifier: GPL-3.0-or-later
+ *
  * Author: Guido Günther <agx@sigxcpu.org>
  *
- * Based on  gnome-shell's shell-keyring-prompt.c
+ * Based on gnome-shell's shell-keyring-prompt.c
  * Author: Stef Walter <stefw@gnome.org>
  */
 
@@ -27,7 +29,7 @@
  * @Title: PhoshPolkitAuthPrompt
  *
  * The #PhoshPolkitAuthPrompt is used to ask policy kit authentication.
- * This handles the interaction with #PolkitAgentSession.
+ * This handles the interaction with PolkitAgentSession.
  */
 
 enum {
@@ -62,10 +64,10 @@ struct _PhoshPolkitAuthPrompt
   GtkWidget *entry_password;
   GtkEntryBuffer *password_buffer;
 
-  gchar *action_id;
-  gchar *message;
-  gchar *icon_name;
-  gchar *cookie;
+  char  *action_id;
+  char  *message;
+  char  *icon_name;
+  char  *cookie;
   GStrv  user_names;
 
   PolkitIdentity *identity;
@@ -80,7 +82,7 @@ static void phosh_polkit_auth_prompt_initiate (PhoshPolkitAuthPrompt *self);
 
 
 static void
-set_action_id (PhoshPolkitAuthPrompt *self, const gchar *action_id)
+set_action_id (PhoshPolkitAuthPrompt *self, const char *action_id)
 {
   g_return_if_fail (PHOSH_IS_POLKIT_AUTH_PROMPT (self));
 
@@ -95,7 +97,7 @@ set_action_id (PhoshPolkitAuthPrompt *self, const gchar *action_id)
 
 
 static void
-set_cookie (PhoshPolkitAuthPrompt *self, const gchar *cookie)
+set_cookie (PhoshPolkitAuthPrompt *self, const char *cookie)
 {
   g_return_if_fail (PHOSH_IS_POLKIT_AUTH_PROMPT (self));
 
@@ -110,7 +112,7 @@ set_cookie (PhoshPolkitAuthPrompt *self, const gchar *cookie)
 
 
 static void
-set_message (PhoshPolkitAuthPrompt *self, const gchar *message)
+set_message (PhoshPolkitAuthPrompt *self, const char *message)
 {
   g_return_if_fail (PHOSH_IS_POLKIT_AUTH_PROMPT (self));
 
@@ -126,7 +128,7 @@ set_message (PhoshPolkitAuthPrompt *self, const gchar *message)
 
 
 static void
-set_icon_name (PhoshPolkitAuthPrompt *self, const gchar *icon_name)
+set_icon_name (PhoshPolkitAuthPrompt *self, const char *icon_name)
 {
   g_return_if_fail (PHOSH_IS_POLKIT_AUTH_PROMPT (self));
 
@@ -145,9 +147,9 @@ set_icon_name (PhoshPolkitAuthPrompt *self, const gchar *icon_name)
 static void
 set_user_names (PhoshPolkitAuthPrompt *self, const GStrv user_names)
 {
-  const gchar *user_name = NULL;
+  const char *user_name = NULL;
   GError *err = NULL;
-  gint len;
+  int len;
 
   g_return_if_fail (PHOSH_IS_POLKIT_AUTH_PROMPT (self));
 
@@ -167,10 +169,10 @@ set_user_names (PhoshPolkitAuthPrompt *self, const GStrv user_names)
     g_debug ("Received %d user names, only using one", len);
     user_name = g_get_user_name();
 
-    if (!g_strv_contains ((const gchar * const *)user_names, user_name))
+    if (!g_strv_contains ((const char *const *)user_names, user_name))
       user_name = "root";
 
-    if (!g_strv_contains ((const gchar * const *)user_names, user_name))
+    if (!g_strv_contains ((const char *const *)user_names, user_name))
       user_name = user_names[0];
   };
 
@@ -262,7 +264,7 @@ emit_done (PhoshPolkitAuthPrompt *self, gboolean cancelled)
 
 static void
 on_auth_session_request (PhoshPolkitAuthPrompt *self,
-                         gchar                 *request,
+                         char                  *request,
                          gboolean               echo_on,
                          gpointer               user_data)
 {
@@ -278,11 +280,12 @@ on_auth_session_request (PhoshPolkitAuthPrompt *self,
   gtk_label_set_text(GTK_LABEL (self->lbl_password), request);
   gtk_entry_set_visibility (GTK_ENTRY (self->entry_password), echo_on);
   gtk_entry_set_text (GTK_ENTRY (self->entry_password), "");
+  gtk_widget_grab_focus (self->entry_password);
 }
 
 static void
 on_auth_session_show_error (PhoshPolkitAuthPrompt *self,
-                            gchar                 *text,
+                            char                  *text,
                             PolkitAgentSession    *session)
 {
   g_debug ("%s", text);
@@ -292,7 +295,7 @@ on_auth_session_show_error (PhoshPolkitAuthPrompt *self,
 
 static void
 on_auth_session_show_info (PhoshPolkitAuthPrompt *self,
-                           gchar                 *text,
+                           char                  *text,
                            PolkitAgentSession    *session)
 {
   g_debug ("%s", text);
@@ -372,7 +375,7 @@ on_btn_cancel_clicked (PhoshPolkitAuthPrompt *self, GtkButton *btn)
 static void
 on_btn_authenticate_clicked (PhoshPolkitAuthPrompt *self, GtkButton *btn)
 {
-  const gchar *password;
+  const char *password;
 
   password = gtk_entry_buffer_get_text (self->password_buffer);
 
@@ -386,22 +389,6 @@ on_btn_authenticate_clicked (PhoshPolkitAuthPrompt *self, GtkButton *btn)
 }
 
 
-static gboolean
-draw_cb (GtkWidget *widget, cairo_t *cr, gpointer unused)
-{
-  GtkStyleContext *context = gtk_widget_get_style_context (widget);
-  GdkRGBA c;
-
-  G_GNUC_BEGIN_IGNORE_DEPRECATIONS
-    gtk_style_context_get_background_color (context, GTK_STATE_FLAG_NORMAL, &c);
-  G_GNUC_END_IGNORE_DEPRECATIONS
-    cairo_set_source_rgba (cr, c.red, c.green, c.blue, 0.7);
-  cairo_set_operator (cr, CAIRO_OPERATOR_SOURCE);
-  cairo_paint (cr);
-  return FALSE;
-}
-
-
 static gboolean
 on_key_press_event (PhoshPolkitAuthPrompt *self, GdkEventKey *event, gpointer data)
 {
@@ -429,6 +416,7 @@ phosh_polkit_auth_prompt_dispose (GObject *obj)
   PhoshPolkitAuthPrompt *self = PHOSH_POLKIT_AUTH_PROMPT (obj);
 
   g_clear_object (&self->identity);
+  g_clear_object (&self->session);
 
   G_OBJECT_CLASS (phosh_polkit_auth_prompt_parent_class)->dispose (obj);
 }
@@ -460,12 +448,6 @@ phosh_polkit_auth_prompt_constructed (GObject *object)
   gtk_entry_set_buffer (GTK_ENTRY (self->entry_password),
                         GTK_ENTRY_BUFFER (self->password_buffer));
 
-  gtk_widget_set_app_paintable(GTK_WIDGET (self), TRUE);
-  g_signal_connect (G_OBJECT(self),
-                    "draw",
-                    G_CALLBACK(draw_cb),
-                    NULL);
-
   g_signal_connect_object (self->btn_cancel,
                            "clicked",
                            G_CALLBACK (on_btn_cancel_clicked),
@@ -575,10 +557,10 @@ phosh_polkit_auth_prompt_init (PhoshPolkitAuthPrompt *self)
 
 
 GtkWidget *
-phosh_polkit_auth_prompt_new (const gchar *action_id,
-                              const gchar *message,
-                              const gchar *icon_name,
-                              const gchar *cookie,
+phosh_polkit_auth_prompt_new (const char *action_id,
+                              const char *message,
+                              const char *icon_name,
+                              const char *cookie,
                               GStrv user_names,
                               gpointer layer_shell,
                               gpointer wl_output)
