@@ -1,7 +1,7 @@
 /*
  * Copyright (C) 2019 Purism SPC
  *
- * SPDX-License-Identifier: GPL-3.0+
+ * SPDX-License-Identifier: GPL-3.0-or-later
  */
 
 #pragma once
@@ -22,12 +22,12 @@ struct _PhoshStatusIconClass
 GtkWidget * phosh_status_icon_new (void);
 void phosh_status_icon_set_icon_size (PhoshStatusIcon *self, GtkIconSize size);
 GtkIconSize phosh_status_icon_get_icon_size (PhoshStatusIcon *self);
-void phosh_status_icon_set_icon_name (PhoshStatusIcon *self, const gchar *icon_name);
-gchar * phosh_status_icon_get_icon_name (PhoshStatusIcon *self);
+void phosh_status_icon_set_icon_name (PhoshStatusIcon *self, const char *icon_name);
+char *phosh_status_icon_get_icon_name (PhoshStatusIcon *self);
 void phosh_status_icon_set_extra_widget (PhoshStatusIcon *self, GtkWidget *widget);
 GtkWidget * phosh_status_icon_get_extra_widget (PhoshStatusIcon *self);
-void phosh_status_icon_set_info (PhoshStatusIcon *self, const gchar *info);
-gchar * phosh_status_icon_get_info (PhoshStatusIcon *self);
+void phosh_status_icon_set_info (PhoshStatusIcon *self, const char *info);
+char *phosh_status_icon_get_info (PhoshStatusIcon *self);
 void phosh_status_icon_set_show_always (PhoshStatusIcon *self, gboolean show_always);
 gboolean phosh_status_icon_get_show_always (PhoshStatusIcon *self);
 
