@@ -1,9 +1,11 @@
 /*
  * Copyright (C) 2018 Purism SPC
- * SPDX-License-Identifier: GPL-3.0+
+ *
+ * SPDX-License-Identifier: GPL-3.0-or-later
+ *
  * Author: Guido Günther <agx@sigxcpu.org>
  *
- * Based on  gnome-shell's shell-keyring-prompt.c
+ * Based on gnome-shell's shell-keyring-prompt.c
  * Author: Stef Walter <stefw@gnome.org>
  */
 
@@ -60,16 +62,16 @@ typedef enum
 
 typedef struct
 {
-  gchar *title;
-  gchar *message;
-  gchar *description;
-  gchar *warning;
-  gchar *choice_label;
+  char *title;
+  char *message;
+  char *description;
+  char *warning;
+  char *choice_label;
   gboolean choice_chosen;
   gboolean password_new;
   guint password_strength;
-  gchar *continue_label;
-  gchar *cancel_label;
+  char *continue_label;
+  char *cancel_label;
 
   GtkWidget *btn_cancel;
   GtkWidget *btn_continue;
@@ -259,6 +261,7 @@ phosh_system_prompt_password_async (GcrPrompt *prompt,
   if (!gtk_entry_get_text_length (GTK_ENTRY (priv->entry_password)))
     gtk_widget_set_sensitive (priv->btn_continue, FALSE);
   gtk_widget_set_sensitive (priv->grid, TRUE);
+  gtk_widget_grab_focus (priv->entry_password);
 
   obj = G_OBJECT (self);
   g_object_notify (obj, "password-visible");
@@ -269,7 +272,7 @@ phosh_system_prompt_password_async (GcrPrompt *prompt,
 }
 
 
-static const gchar *
+static const char *
 phosh_system_prompt_password_finish (GcrPrompt *prompt,
                                      GAsyncResult *result,
                                      GError **error)
@@ -317,6 +320,7 @@ phosh_system_prompt_confirm_async (GcrPrompt *prompt,
 
   gtk_widget_set_sensitive (priv->btn_continue, TRUE);
   gtk_widget_set_sensitive (priv->grid, TRUE);
+  gtk_widget_grab_focus (priv->entry_confirm);
 
   obj = G_OBJECT (self);
   g_object_notify (obj, "password-visible");
@@ -352,9 +356,9 @@ prompt_complete (PhoshSystemPrompt *self)
   PhoshSystemPromptPrivate *priv = phosh_system_prompt_get_instance_private (self);
   GTask *res;
   PromptingMode mode;
-  const gchar *password;
-  const gchar *confirm;
-  const gchar *env;
+  const char *password;
+  const char *confirm;
+  const char *env;
 
   g_return_val_if_fail (PHOSH_IS_SYSTEM_PROMPT (self), FALSE);
   g_return_val_if_fail (priv->mode != PROMPTING_NONE, FALSE);
@@ -440,7 +444,7 @@ on_password_changed (PhoshSystemPrompt *self,
   PhoshSystemPromptPrivate *priv;
   int upper, lower, digit, misc;
   const char *password;
-  gdouble pwstrength;
+  double pwstrength;
   int length, i;
 
   g_return_if_fail (PHOSH_IS_SYSTEM_PROMPT (self));
@@ -524,21 +528,6 @@ phosh_system_prompt_iface_init (GcrPromptIface *iface)
   iface->prompt_close = phosh_system_prompt_close;
 }
 
-static gboolean
-draw_cb (GtkWidget *widget, cairo_t *cr, gpointer unused)
-{
-  GtkStyleContext *context = gtk_widget_get_style_context (widget);
-  GdkRGBA c;
-
-  G_GNUC_BEGIN_IGNORE_DEPRECATIONS
-    gtk_style_context_get_background_color (context, GTK_STATE_FLAG_NORMAL, &c);
-  G_GNUC_END_IGNORE_DEPRECATIONS
-    cairo_set_source_rgba (cr, c.red, c.green, c.blue, 0.7);
-  cairo_set_operator (cr, CAIRO_OPERATOR_SOURCE);
-  cairo_paint (cr);
-  return FALSE;
-}
-
 
 static gboolean
 on_key_press_event (PhoshSystemPrompt *self, GdkEventKey *event, gpointer data)
@@ -647,12 +636,6 @@ phosh_system_prompt_constructed (GObject *object)
                            G_CONNECT_SWAPPED);
   gtk_widget_grab_default (priv->btn_continue);
 
-  gtk_widget_set_app_paintable(GTK_WIDGET (self), TRUE);
-  g_signal_connect (G_OBJECT(self),
-                    "draw",
-                    G_CALLBACK(draw_cb),
-                    NULL);
-
   gtk_widget_add_events (GTK_WIDGET (self), GDK_KEY_PRESS_MASK);
   g_signal_connect (G_OBJECT (self),
                     "key_press_event",
