@@ -1,7 +1,7 @@
 /*
  * Copyright (C) 2019 Purism SPC
  *
- * SPDX-License-Identifier: GPL-3.0+
+ * SPDX-License-Identifier: GPL-3.0-or-later
  */
 
 #pragma once
@@ -18,8 +18,8 @@ G_DECLARE_FINAL_TYPE (PhoshToplevel,
                       GObject)
 
 PhoshToplevel *phosh_toplevel_new_from_handle (struct zwlr_foreign_toplevel_handle_v1 *handle);
-const gchar *phosh_toplevel_get_title (PhoshToplevel *self);
-const gchar *phosh_toplevel_get_app_id (PhoshToplevel *self);
+const char *phosh_toplevel_get_title (PhoshToplevel *self);
+const char *phosh_toplevel_get_app_id (PhoshToplevel *self);
 struct zwlr_foreign_toplevel_handle_v1 *phosh_toplevel_get_handle (PhoshToplevel *self);
 gboolean phosh_toplevel_is_configured (PhoshToplevel *self);
 gboolean phosh_toplevel_is_activated (PhoshToplevel *self);
