@@ -1,6 +1,8 @@
 /*
  * Copyright (C) 2019 Purism SPC
- * SPDX-License-Identifier: GPL-3.0+
+ *
+ * SPDX-License-Identifier: GPL-3.0-or-later
+ *
  * Author: Guido Günther <agx@sigxcpu.org>
  */
 
@@ -49,8 +51,8 @@ struct _PhoshWifiManager
    * connection state */
   gboolean           present;
 
-  const gchar        *icon_name;
-  gchar              *ssid;
+  const char         *icon_name;
+  char               *ssid;
 
   NMClient           *nmclient;
   /* The access point we're connected to */
@@ -81,7 +83,7 @@ signal_strength_icon_name (guint strength)
 }
 
 
-static const gchar *
+static const char *
 get_icon_name (PhoshWifiManager *self)
 {
   NMActiveConnectionState state;
@@ -119,7 +121,7 @@ get_icon_name (PhoshWifiManager *self)
 static void
 update_icon_name (PhoshWifiManager *self)
 {
-  const gchar *old_icon_name;
+  const char *old_icon_name;
   g_return_if_fail (PHOSH_IS_WIFI_MANAGER (self));
 
   old_icon_name = self->icon_name;
@@ -213,7 +215,7 @@ on_nm_device_wifi_active_access_point_changed (PhoshWifiManager *self, GParamSpe
 {
   NMAccessPoint *old_ap;
   GBytes *ssid;
-  g_autofree gchar *old_ssid = NULL;
+  g_autofree char *old_ssid = NULL;
 
   g_return_if_fail (PHOSH_IS_WIFI_MANAGER (self));
   g_return_if_fail (NM_IS_DEVICE_WIFI (dev));
@@ -466,14 +468,20 @@ network_agent_setup_prompt (PhoshWifiManager *self)
   g_signal_connect_object (self->network_prompt, "done",
                            G_CALLBACK (network_prompt_done_cb),
                            self, G_CONNECT_SWAPPED);
+
+  /* Show widget when not locked and keep that in sync */
+  g_object_bind_property (phosh_shell_get_default (), "locked",
+                          self->network_prompt, "visible",
+                          G_BINDING_SYNC_CREATE | G_BINDING_INVERT_BOOLEAN);
 }
 
+
 static void
 secret_request_new_cb (PhoshWifiManager              *self,
-                       gchar                         *request_id,
+                       char                          *request_id,
                        NMConnection                  *connection,
-                       gchar                         *setting_name,
-                       gchar                        **hints,
+                       char                          *setting_name,
+                       char                         **hints,
                        NMSecretAgentGetSecretsFlags   flags,
                        ShellNetworkAgent             *agent)
 {
@@ -484,18 +492,19 @@ secret_request_new_cb (PhoshWifiManager              *self,
     return;
   }
 
-  if (!self->network_prompt)
-    network_agent_setup_prompt (self);
+  g_return_if_fail (!self->network_prompt);
 
+  network_agent_setup_prompt (self);
   phosh_network_auth_prompt_set_request (self->network_prompt,
                                          request_id, connection, setting_name,
                                          hints, flags);
-  gtk_widget_show (GTK_WIDGET (self->network_prompt));
+
 }
 
+
 static void
 secret_request_cancelled_cb (PhoshWifiManager  *self,
-                             gchar             *request_id,
+                             char              *request_id,
                              ShellNetworkAgent *agent)
 {
   g_return_if_fail (PHOSH_IS_WIFI_MANAGER (self));
@@ -687,7 +696,7 @@ phosh_wifi_manager_get_strength (PhoshWifiManager *self)
   return nm_access_point_get_strength (self->ap);
 }
 
-const gchar*
+const char *
 phosh_wifi_manager_get_icon_name (PhoshWifiManager *self)
 {
   g_return_val_if_fail (PHOSH_IS_WIFI_MANAGER (self), NULL);
@@ -696,7 +705,7 @@ phosh_wifi_manager_get_icon_name (PhoshWifiManager *self)
 }
 
 
-const gchar*
+const char *
 phosh_wifi_manager_get_ssid (PhoshWifiManager *self)
 {
   g_return_val_if_fail (PHOSH_IS_WIFI_MANAGER (self), NULL);
