@@ -1,7 +1,7 @@
 /*
  * Copyright (C) 2019 Purism SPC
  *
- * SPDX-License-Identifier: GPL-3.0+
+ * SPDX-License-Identifier: GPL-3.0-or-later
  */
 
 #pragma once
@@ -16,8 +16,8 @@ G_DECLARE_FINAL_TYPE (PhoshWifiManager, phosh_wifi_manager, PHOSH, WIFI_MANAGER,
 
 PhoshWifiManager  *phosh_wifi_manager_new (void);
 guint8             phosh_wifi_manager_get_strength (PhoshWifiManager *self);
-const gchar       *phosh_wifi_manager_get_icon_name (PhoshWifiManager *self);
-const gchar       *phosh_wifi_manager_get_ssid (PhoshWifiManager *self);
+const char        *phosh_wifi_manager_get_icon_name (PhoshWifiManager *self);
+const char        *phosh_wifi_manager_get_ssid (PhoshWifiManager *self);
 gboolean           phosh_wifi_manager_get_enabled (PhoshWifiManager *self);
 gboolean           phosh_wifi_manager_get_present (PhoshWifiManager *self);
 
