@@ -1,7 +1,7 @@
 /*
  * Copyright (C) 2018 Purism SPC
  *
- * SPDX-License-Identifier: GPL-3.0+
+ * SPDX-License-Identifier: GPL-3.0-or-later
  */
 #pragma once
 
@@ -12,6 +12,19 @@ G_BEGIN_DECLS
 #define PHOSH_TYPE_WWAN (phosh_wwan_get_type())
 G_DECLARE_INTERFACE (PhoshWWan, phosh_wwan, PHOSH, WWAN, GObject)
 
+/**
+ * PhoshWWanInterface
+ * @parent_iface: The parent interface
+ * @get_signal_quality: Get the current signal quality
+ * @get_access_tec: Get the current access technology (2G, 3G, ...)
+ * @is_unlocked: whether the SIM in the modem is locked
+ * @has_sim: Whether there's a sim in the modem
+ * @is_present: whether a modem is present at all
+ * @get_operator: Get the current network operator name
+ *
+ * Provides an interface for interacting with a modem
+*/
+
 struct _PhoshWWanInterface
 {
   GTypeInterface parent_iface;
@@ -29,4 +42,4 @@ const char*   phosh_wwan_get_access_tec     (PhoshWWan* self);
 gboolean      phosh_wwan_is_unlocked        (PhoshWWan* self);
 gboolean      phosh_wwan_has_sim            (PhoshWWan* self);
 gboolean      phosh_wwan_is_present         (PhoshWWan* self);
-const gchar  *phosh_wwan_get_operator       (PhoshWWan *self);
+const char   *phosh_wwan_get_operator       (PhoshWWan *self);
