@@ -1,3 +1,9 @@
+/*
+ * Copyright (C) 2018 Purism SPC
+ *
+ * SPDX-License-Identifier: GPL-3.0-or-later
+ */
+
 /* Stubs so we don't need to run the shell */
 
 #include <glib.h>
@@ -13,7 +19,7 @@ phosh_shell_get_default (void)
 }
 
 void
-phosh_shell_get_usable_area (PhoshShell *self,  gint *x, gint *y, gint *width, gint *height)
+phosh_shell_get_usable_area (PhoshShell *self, int *x, int *y, int *width, int *height)
 {
   if (x)
     *x = 16;
@@ -37,3 +43,9 @@ phosh_shell_get_toplevel_manager (PhoshShell *self)
 {
   return g_object_new (PHOSH_TYPE_TOPLEVEL_MANAGER, NULL);
 }
+
+GdkAppLaunchContext*
+phosh_shell_get_app_launch_context (PhoshShell *self)
+{
+  return gdk_display_get_app_launch_context (gdk_display_get_default ());
+}
