@@ -1,6 +1,8 @@
 /*
  * Copyright (C) 2018 Purism SPC
- * SPDX-License-Identifier: GPL-3.0+
+ *
+ * SPDX-License-Identifier: GPL-3.0-or-later
+ *
  * Author: Guido Günther <agx@sigxcpu.org>
  */
 
@@ -18,12 +20,12 @@ test_phosh_overview_new(void)
 }
 
 
-gint
-main (gint argc,
-      gchar *argv[])
+int
+main (int   argc,
+      char *argv[])
 {
   gtk_test_init (&argc, &argv, NULL);
-  hdy_init (&argc, &argv);
+  hdy_init ();
 
   g_test_add_func("/phosh/overview/new", test_phosh_overview_new);
   return g_test_run();
